@@ -1,5 +1,11 @@
 from __future__ import annotations
-from typing import Final, List, Optional, Sequence, Tuple
+from typing import List, Optional, Sequence, Tuple
+import sys
+
+if sys.version_info < (3, 8):
+    from typing_extensions import Final
+else:
+    from typing import Final
 
 from lxml import etree
 
@@ -9,7 +15,7 @@ from unstructured.cleaners.core import clean_bullets, replace_unicode_quotes
 from unstructured.documents.base import Page
 from unstructured.documents.elements import ListItem, Element, NarrativeText, Title
 from unstructured.documents.xml import XMLDocument
-from unstructured.nlp.partition import (
+from unstructured.partition.text_type import (
     is_bulleted_text,
     is_possible_narrative_text,
     is_possible_title,
